<template>
  <div class="skin-dropdown">
    <Poptip v-model="visible" transfer popper-class="skin">
      <a>
        <slot>
          <span class="icon-text">换肤</span>
        </slot>
        <Icon :size="18" color="#fff" type="md-arrow-dropdown"></Icon>
      </a>
      <template #content>
        <ul class="skin-list">
          <li v-for="skin in skinList" :key="skin.label">
            <Tooltip :content="skin.title">
              <a
                href="javascript:;"
                :style="{ 'background-color': skin.color }"
                :class="{ active: curSkin == skin.label }"
                @click="onClick(skin)"
              ></a>
            </Tooltip>
          </li>
        </ul>
      </template>
    </Poptip>
  </div>
</template>

<script>
import { localSave, localRead } from "@/libs/util";
import { showError } from "@/libs/util";
const skinKey = "skin";
export default {
  name: "LayoutSkin",
  data() {
    return {
      visible: false,
      linkId: "skin",
      curSkin: "",
      skinList: [
        {
          title: "浅色",
          label: "light",
          color: "#2db7f5",
        },
        {
          title: "深色",
          label: "dark",
          color: "#404040",
        },
        {
          title: "红色",
          label: "red",
          color: "#cb1b59",
        },
        {
          title: "绿色",
          label: "green",
          color: "#3fa329",
        },
        {
          title: "紫色",
          label: "purple",
          color: "#415aca",
        },
        {
          title: "蓝色",
          label: "blue",
          color: "#138ec7",
        },
      ],
    };
  },
  methods: {
    close() {
      this.visible = false;
    },
    async onClick(skin) {
      if (this.curSkin == skin.label) return this.close();

      this.curSkin = skin.label;
      localSave(skinKey, skin.label);
      
      await this.changeSkin(skin);
      this.close();
    },
    async changeSkin(skin) {
      var skinLink = this.getSkinLink();
      var linkUrl = this.getLinkUrl(skin);

      if (!skin.label) {
        document.head.removeChild(skinLink);
      }

      try {
        let res = await (await fetch(linkUrl)).text();
        skinLink.innerHTML = res || "";
      } catch (ex) {
        this.showError(`加载皮肤文件${linkUrl}失败`);
      }
    },
    getSkinLink() {
      let link = document.querySelector("#" + this.linkId);
      if (!link) {
        link = document.createElement("style");
        link.type = "text/css";
        link.id = this.linkId;
        document.head.appendChild(link);
      }
      return link;
    },
    getLinkUrl(skin) {
      return `${window.skinRoot}/${skin.label}.css`;
    },
    loadSkin(skin) {
      this.curSkin = skin.label;
      this.changeSkin(skin);
    },
    showError(ex) {
      showError(this, ex);
    },
  },
  mounted() {
    let skin;
    const curSkin = localRead(skinKey) || "light";
    if (curSkin) skin = this.skinList.find((l) => l.label == curSkin);
    this.loadSkin(skin);
  },
};
</script>

<style lang="less" scoped>
.skin-dropdown {
  margin-right: 10px;
  float: right;
  a {
    color: #fff;
  }
}
</style>
<style lang="less">
.skin {
  .ivu-poptip-body-content {
    overflow: hidden;
  }
  .skin-list {
    list-style: none;
    width: 144px;
    &:after {
      content: "";
      display: table;
      clear: both;
    }
    li {
      margin: 2px;
      width: 20px;
      height: 20px;
      float: left;
      a {
        width: 20px;
        height: 20px;
        display: inline-block;
        &.active {
          box-shadow: 0 0 0 2px rgba(45, 140, 240, 0.2);
        }
      }
    }
  }
}
</style>